@@ -30,6 +30,13 @@
 
 #include "kiocore_export.h"
 
+namespace KIO
+{
+class UDSEntry;
+}
+
+void debugUDSEntry(QDebug stream, const KIO::UDSEntry &entry);
+
 namespace KIO
 {
 class UDSEntryPrivate;
@@ -276,6 +283,7 @@ public:
 
 private:
     friend class UDSEntryPrivate;
+    friend void ::debugUDSEntry(QDebug stream, const KIO::UDSEntry &entry);
     QSharedDataPointer<UDSEntryPrivate> d;
 };
 
@@ -308,6 +316,12 @@ typedef QList<UDSEntry> UDSEntryList;
 KIOCORE_EXPORT QDataStream &operator<< (QDataStream &s, const KIO::UDSEntry &a);
 KIOCORE_EXPORT QDataStream &operator>> (QDataStream &s, KIO::UDSEntry &a);
 
+/**
+ * Support for qDebug() << aUDSEntry
+ * \since 5.22
+ */
+KIOCORE_EXPORT QDebug operator<<(QDebug stream, const KIO::UDSEntry &entry);
+
 Q_DECLARE_METATYPE(KIO::UDSEntry)
 
 #endif /*UDSENTRY_H*/
